@@ -20,27 +20,25 @@
 #' @export
 #' @aliases bladderMALDIRompp2010
 #'
-bladderMALDIRompp2010 <- function(verbose = TRUE)
-{
+bladderMALDIRompp2010 <- function(verbose = TRUE) {
   maldiData <- NULL
-  
-  if (verbose)
-  {
+
+  if (verbose) {
     cat("Downloading the data from the repository...\n")
   }
-  
+
   addr <- "https://raw.github.com/paoloinglese/SPUTNIKexamples/master/data/maldiData.rda"
   z <- paste0(tempfile(), ".rda")
   tryCatch(download.file(addr, z, mode = "wb"),
-           error = function(e) {
-             stop(e)
-           })
-  
-  if (verbose)
-  {
+    error = function(e) {
+      stop(e)
+    }
+  )
+
+  if (verbose) {
     cat("Loading the data in the R environment...\n")
   }
-  
+
   load(z)
   ## Delete the temporary file
   file.remove(z)
@@ -70,27 +68,25 @@ bladderMALDIRompp2010 <- function(verbose = TRUE)
 #' @export
 #' @aliases ovarianDESIDoria2016
 #'
-ovarianDESIDoria2016 <- function(verbose = TRUE)
-{
+ovarianDESIDoria2016 <- function(verbose = TRUE) {
   desiData <- NULL
-  
-  if (verbose)
-  {
+
+  if (verbose) {
     cat("Downloading the data from the repository...\n")
   }
-  
+
   addr <- "https://raw.github.com/paoloinglese/SPUTNIKexamples/master/data/desiData.rda"
   z <- paste0(tempfile(), ".RData")
   tryCatch(download.file(addr, z, mode = "wb"),
-           error = function(e) {
-             stop(e)
-           })
-  
-  if (verbose)
-  {
+    error = function(e) {
+      stop(e)
+    }
+  )
+
+  if (verbose) {
     cat("Loading the data in the R environment...\n")
   }
-  
+
   load(z)
   ## Delete the temporary file
   file.remove(z)
